#
# spec file for package gnubg
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2003 Achim Mueller, Germany.
# Updated by Christopher Hofmann in 2010
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           gnubg
Version:        1.04.001
Release:        6.16
Summary:        Plays and analyzes backgammon games and matches on a world class level
License:        GPL-3.0+
Group:          Amusements/Games/Board/Other
Url:            http://www.gnubg.org
Source:         http://gnubg.org/media/sources/gnubg-release-%{version}-sources.tar.gz
Source1:        %{name}.desktop
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  freetype2-devel
BuildRequires:  glibc-devel
%if 0%{?suse_version} != 1230
BuildRequires:  glu-devel
BuildRequires:  gtkglext-devel
%endif
BuildRequires:  gmp-devel
BuildRequires:  libcanberra-devel
BuildRequires:  libpng-devel
BuildRequires:  libtool
BuildRequires:  python-devel
BuildRequires:  readline-devel
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} > 1120
BuildRequires:  libpng-devel >= 1.4
%else
BuildRequires:  libpng-devel
%endif
%if 0%{?suse_version}
BuildRequires:  update-desktop-files
Recommends:     gnubg-databases = %{version}
Recommends:     gnubg-sounds = %{version}
Recommends:     gnubg-doc = %{version}
Recommends:     python-MySQL-python
BuildRequires:  sqlite3-devel
%endif
%if 0%{?fedora}
BuildRequires:  sqlite-devel
%endif
Recommends:     %{name}-lang

%description
Program for playing and analysing backgammon positions, games and matches. It is
based on a neural network. It currently plays at about the level of a
championship flight tournament player. Depending on its parameters and its luck
in recent games, it rates from around 1900 to 2000 on FIBS, the First Internet
Backgammon Server -- at its strongest, it ranks in the top 5 of over 6000 rated
players there and is gradually improving.

%package databases
Summary:        Bearoff databases for gnubg
License:        GPL-3.0+
Group:          Amusements/Games/Board/Other
Requires:       %{name} = %{version}

%description databases
Precalculated GNU Backgammon bearoff databases - its intelligence. If you prefer
a stronger or weaker opponent calculate you own with tweaked parameters
according to the documentation.

%package sounds
Summary:        Sounds for gnubg
License:        GPL-3.0+
Group:          Amusements/Games/Board/Other
Requires:       %{name} = %{version}

%description sounds
Sounds for GNU Backgammon. See description of gnubg for more details.

%package doc
Summary:        Documentation for gnubg
License:        GFDL-1.3
Group:          Amusements/Games/Board/Other

%description doc
Manual for GNU Backgammon. See description of gnubg for more details.

%lang_package

%prep
%setup -q gnubg
# if we have a glib-gettext.m4 installed in the system, we drop the
# local copy in gnubg. It certainly is older
if [ -f %{_datadir}/aclocal/glib-gettext.m4 ]; then
  rm m4/glib-gettext.m4
fi

%build
autoreconf -fi
export SUSE_ASNEEDED=1
%configure --docdir=%{_docdir}/%{name}
make %{?_smp_mflags}

%install
%make_install

DOC="ABOUT-NLS COPYING NEWS README TODO"
install -m 0644 $DOC %{buildroot}/%{_docdir}/%{name}/

%if 0%{?suse_version}
%suse_update_desktop_file -i %{name}
%endif
%find_lang %{name}

%files
%defattr(-,root,root)
%{_bindir}/*
%{_mandir}/man?/%{name}*
%{_mandir}/man?/bearoffdump.*
%{_mandir}/man?/makebearoff.*
%{_mandir}/man?/makehyper.*
%{_mandir}/man?/makeweights.*

%if 0%{?suse_version}
%{_datadir}/applications/gnubg.desktop
%endif
%{_datadir}/icons/hicolor/*/apps/gnubg.png
%{_datadir}/gnubg
%attr(755, -, root) %{_datadir}/gnubg/scripts/query_player.sh
%exclude %{_datadir}/gnubg/*.bd
%exclude %{_datadir}/gnubg/sounds
%doc %{_docdir}/%{name}
%exclude %{_docdir}/%{name}/images
%exclude %{_docdir}/%{name}/gnubg.html
%exclude %{_docdir}/%{name}/allabout.html

%files databases
%defattr(-,root,root)
%{_datadir}/gnubg/*.bd

%files sounds
%defattr(-,root,root)
%{_datadir}/gnubg/sounds

%files doc
%defattr(-,root,root)
%doc %{_docdir}/%{name}/images
%doc %{_docdir}/%{name}/gnubg.html
%doc %{_docdir}/%{name}/allabout.html

%files lang -f %{name}.lang

%changelog
* Mon Apr 18 2016 dimstar@opensuse.org
- Remove local copy of glib-gettext.m4 in case we have one
  available on the system. It can't be older than what gnubg ships.
* Thu Jan 15 2015 p.drouand@gmail.com
- Update to version 1.04.001
  + play.c. external.c : Fix external interface bug that prevented
  external socket players from working. Fix bug that prevented
  external socket interface errors being displayed.
  https://savannah.gnu.org/bugs/?43747
- Split out language files in their own subpackage
- Make main package recommend gnubg-lang
* Tue Aug  5 2014 cwh@suse.com
- 1.03.000
- added recommends: python-MySQL-python
- removed patches docdir.patch and glu.patch since these things
  are now fixed upstream.
* Wed Sep 18 2013 cwh@suse.com
- Leaving tarball as gz
* Tue Aug 20 2013 cwh@suse.com
- (Re)Enabled 3d board by fixing GLU linking (oS!=12.3)
* Mon Aug 19 2013 cwh@suse.com
- Update to 1.02.000
- Improved performance (speed)
- Support for AVX(SIMD)
- Better Python support
- Stronger neural network
- Even/Odd ply effect reduced
- Some analysis options have been simplified
- Various miscellaneous bug fixes
* Mon Jul 29 2013 cwh@suse.com
- Updated to snapshot 20130725
* Mon Sep  3 2012 idonmez@suse.com
- Disable gtkglext-devel dependency for openSUSE > 12.2
* Thu Jul 19 2012 cwh@suse.com
- first try to make it building for Fedora 17
* Wed Jul 11 2012 cwh@suse.com
- updated to snapshot 20120711
- cleaned specfile
* Tue Mar  1 2011 cwh@novell.com
- updated to snapshot 20110301
* Tue Aug 17 2010 cwh@novell.com
- updated to snapshot 20100817
* Mon Aug  2 2010 cwh@novell.com
- updated to snapshot 20100802
* Tue Jun 22 2010 cwh@novell.com
- updated to snapshot 20100622
* Tue Jun 15 2010 cwh@novell.com
- let doc going to proper docdir
* Sat Jun 12 2010 cwh@novell.com
- moved desktop file out of the spec file
- updated to most recent svn snapshot
* Tue Jun  1 2010 cwh@novell.com
- imported patch from upstream:
  - made used libpngversion more flexible
  - better fix for buffer overflow
* Fri May 28 2010 cwh@novell.com
- added desktop file
- use libpng 1.4 for Factory (11.3)
- updated package description
* Fri May 21 2010 cwh@novell.com
- fixing fedora build (libpng version)
* Thu May 20 2010 cwh@novell.com
- fix building on >11.2 by requiring libpng less than 1.4
- wrap long BuildRequires
* Wed May 19 2010 cwh@novell.com
- fixed buffer overflow
- fixed filelist
- added debug packages
* Tue May 18 2010 cwh@novell.com
- updated to 0.9.0
- fixed specfile for openSUSE buildservice and current distributions
* Sat Nov 18 2006 ace@gnubg.org
- some slight changes in specfile
* Tue Dec 28 2004 ace@gnubg.org
- new weights including pruning
* Mon Oct 11 2004 ace@gnubg.org
- fixed some minor bugs
* Wed Sep  1 2004 ace@gnubg.org
- new rpms with 3d enabled
* Wed Nov  5 2003 ace@gnubg.org
- made the spec suit to redhat and suse <ace@gnubg.org>
- disabled 3d (still problems with nvidia)
- added gpg signature
* Thu Oct 23 2003 ace@gnubg.org
- disabled gdbm and guile
- changed info- and manpath
* Mon Oct 20 2003 ace@gnubg.org
- divided into three packages (gnubg, databases, sounds)
* Sat Oct 18 2003 ace@gnubg.org
- initial package (Version 0.14)
